==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-switch/xl-react-widget-switch.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import {
    computeInitialState,
    computeNextPropsState,
    computeNextState,
    getValidators
} from '../../services/component-service';
import {getModelValue, isComponentDisabled, resetPristinity} from '../../utils/components-utils';
import RU from '../../utils/ramda-utils';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';
import {XlReactWidgetContainerProps} from '../xl-react-widget-props';
import {XlReactWidgetSwitchComponent} from './xl-react-widget-switch-component';

import './xl-react-widget-switch.less';

export class XlReactWidgetSwitch extends PureComponent {
    static propTypes = {
        className: PropTypes.string,
        disabled: PropTypes.bool,
        metadata: PropTypes.shape({
            label: PropTypes.string,
            required: PropTypes.bool
        }),
        model: PropTypes.bool.isRequired,
        onModelChange: PropTypes.func.isRequired,
        onPristinityChange: PropTypes.func,
        renderSwitch: PropTypes.func.isRequired,
        switchClassName: PropTypes.string,
        value: PropTypes.oneOfType([
            PropTypes.string,
            PropTypes.number,
            PropTypes.bool
        ]),
        ...XlReactWidgetContainerProps
    };

    static defaultProps = {metadata: {}, validators: []};

    state = {};

    componentWillMount() {
        const model = getModelValue(this.props, 'model', false);
        computeInitialState(this, this.props, getValidators(this.props), model, false);
        RU.invoke('register', [this.api], this.props);
    }

    componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps), false);
    }

    handleChange = (event) => {
        const {target: {checked}} = event;
        this.applyNewValue(checked);
    };

    api = {
        isPristine: () => this.state.pristine,
        resetPristinity: (config) => resetPristinity(this, this.props, config)
    };

    applyNewValue(model) {
        computeNextState(this, this.props, getValidators(this.props), model);
    }

    render() {
        const {
            className,
            metadata: {required, label},
            model,
            name,
            renderSwitch,
            switchClassName,
            value
        } = this.props;

        const disabled = isComponentDisabled(this.props);

        return <XlReactFormItemControl
            {...{
                ...this.props,
                controlClass: classNames(className, 'xl-react-widget-switch'),
                disabled,
                label,
                required
            }}>
            <XlReactWidgetSwitchComponent
                className={className}
                disabled={disabled}
                model={model}
                name={name}
                onModelChange={this.handleChange}
                renderSwitch={renderSwitch}
                switchClassName={switchClassName}
                value={value}
            />
        </XlReactFormItemControl>;
    }
}

==> xl-react-components-0.21.16.tgz: package/app/xl-react-widget/xl-react-widget-switch/xl-react-widget-switch.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import {
    computeInitialState,
    computeNextPropsState,
    computeNextState,
    getValidators
} from '../../services/component-service';
import {getModelValue, isComponentDisabled, resetPristinity} from '../../utils/components-utils';
import RU from '../../utils/ramda-utils';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';
import {XlReactWidgetContainerProps} from '../xl-react-widget-props';
import {XlReactWidgetSwitchComponent} from './xl-react-widget-switch-component';

import './xl-react-widget-switch.less';

export class XlReactWidgetSwitch extends PureComponent {
    static propTypes = {
        className: PropTypes.string,
        disabled: PropTypes.bool,
        metadata: PropTypes.shape({
            label: PropTypes.string,
            required: PropTypes.bool
        }),
        model: PropTypes.bool.isRequired,
        onModelChange: PropTypes.func.isRequired,
        onPristinityChange: PropTypes.func,
        renderSwitch: PropTypes.func.isRequired,
        switchClassName: PropTypes.string,
        value: PropTypes.oneOfType([
            PropTypes.string,
            PropTypes.number,
            PropTypes.bool
        ]),
        ...XlReactWidgetContainerProps
    };

    static defaultProps = {metadata: {}, validators: []};

    state = {};

    UNSAFE_componentWillMount() {
        const model = getModelValue(this.props, 'model', false);
        computeInitialState(this, this.props, getValidators(this.props), model, false);
        RU.invoke('register', [this.api], this.props);
    }

    UNSAFE_componentWillReceiveProps(nextProps) {
        computeNextPropsState(this, nextProps, this.state, getValidators(nextProps), false);
    }

    handleChange = (event) => {
        const {target: {checked}} = event;
        this.applyNewValue(checked);
    };

    api = {
        isPristine: () => this.state.pristine,
        resetPristinity: (config) => resetPristinity(this, this.props, config)
    };

    applyNewValue(model) {
        computeNextState(this, this.props, getValidators(this.props), model);
    }

    render() {
        const {
            className,
            metadata: {required, label},
            model,
            name,
            renderSwitch,
            switchClassName,
            value
        } = this.props;

        const disabled = isComponentDisabled(this.props);

        return <XlReactFormItemControl
            {...{
                ...this.props,
                controlClass: classNames(className, 'xl-react-widget-switch'),
                disabled,
                label,
                required
            }}>
            <XlReactWidgetSwitchComponent
                className={className}
                disabled={disabled}
                model={model}
                name={name}
                onModelChange={this.handleChange}
                renderSwitch={renderSwitch}
                switchClassName={switchClassName}
                value={value}
            />
        </XlReactFormItemControl>;
    }
}
